@@ -317,7 +317,10 @@ async def check_requirements_latest_versions(
                 logger.error(
                     'search latest version for %s failed: %r', req.name, e
                 )
-        return (req.name, req.specifier, local_version, latest_version)
+        return (
+            req.name, req.specifier, local_version or '', latest_version
+            or '<unknown>'
+        )
 
     async with PyPIDistributions(index_url=pypi_index_url) as pypi_dists:
         tasks = []
@@ -385,6 +388,7 @@ async def search_distributions_by_top_level_import_names(
             *[_collect(pypi_dists, name) for name in names],
             return_exceptions=True
         )
+
     return results, not_found
 
 
